@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'کاتی ناوچەیی میوان',
 	'SYSTEM_TIMEZONE_EXPLAIN'			=> 'کاتی ناوچەیی بۆ نیشاندانی کاتەکان بۆ ئەو بەکارهێنەرانەی کە لە ژوورەوە نین (میوانەکان، بووتەکان). ئەو بەکارهێنەرانەی لە ژوورەوەن لەکاتی تۆماربووندا کاتی ناوچەییان داناوە و دەشتوانن بیگۆڕن لە کۆنترۆڵ پانێڵی خۆیان.',
 	'WARNINGS_EXPIRE'	=> 'ماوەی ئاگاداری',
-	'WARNINGS_EXPIRE_EXPLAIN'	=> 'ژمارەی ڕۆژەکان کە ڕزگاری دەبێت پێ ئاگادارکردنەوە ،خۆکارانە لە تۆماری بەکارهێنەر بەسەردەچێت.',
+	'WARNINGS_EXPIRE_EXPLAIN'	=> 'ژمارەی ڕۆژەکان کە ڕزگاری دەبێت پێ ئاگادارکردنەوە ،خۆکارانە لە تۆماری بەکارهێنەر بەسەردەچێت. ئەو نرخە بە 0 دابنێ بۆ دانانی بە هەمیشەیی.',
 	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'لێرە دەتوانیت چەندین تایبەتمەندی مەکۆ چالاک/ناچالاک بکەیت.',
 	'ALLOW_ATTACHMENTS'	=> 'ڕێدان هاوپێچ',
 	'ALLOW_BIRTHDAYS'	=> 'ڕێدان بە ڕۆژی لە دایکبوون',
@@ -154,7 +154,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'	=> 'زۆرترین بەستەر بۆ هەر پەیامێک',
 	'MAX_POST_URLS_EXPLAIN'	=> 'زۆرترین ژمارەی بەستەر لە پەیامێکدا. 0 بنووسە بۆ بێ سنوور.',
 	'MIN_CHAR_LIMIT'				=> 'کەمترین نووسە بۆ هەر پەیامێک',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'کەمترین ژمارەی نووسە کە بەکارهێنەر پێویستە بینووسێت لە پەیام یان پەیامێکی تایبەتیدا.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'کەمترین ژمارەی نووسە کە بەکارهێنەر پێویستە بینووسێت لە پەیام یان پەیامێکی تایبەتیدا. نرخی 1 کەمترینە بۆ ئەو ڕێکخستنە.',
 	'POSTING'	=> 'پەیام ناردن',
 	'POSTS_PER_PAGE'	=> 'پەیامەکان بۆ هەر پەڕەیەک',
 	'QUOTE_DEPTH_LIMIT'				=> 'زۆرترین فراوانی بۆ ئاماژەکان.',
