@@ -259,6 +259,15 @@ $lang = array_merge($lang, array(
 	'BOARD_VERSION'	=> 'وەشانی مەکۆ',
 	'DATABASE_SERVER_INFO'	=> 'ڕاژەکاری بنکەدراوە',
 	'DATABASE_SIZE'	=> 'قەبارەی بنکەدراوە',
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'بارستایی زیادی نەخشە بە ناڕێکی پەسەندکرا',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> پێویستە نرخەکەی بۆ 0 یان 4 دابنرێت. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'کۆدکردنی ڕۆشنایی تیپەکان بە ناڕێکی پەسەندکرا',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> پێویستە نرخەکەی بۆ 0 دابنرێت. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'گۆڕینی تیپی پشکی HTTP بە ناڕێکی پەسەندکرا',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> پێویستە نرخەکەی دابنرێ بۆ <samp>pass</samp>. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'گۆڕینی تیپی بەرهەمی HTTP بە ناڕێکی پەسەندکرا',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> پێویستە نرخەکەی دابنرێ بۆ <samp>pass</samp>. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
 	'FILES_PER_DAY'	=> 'هاوپێچەکان بۆ هەر ڕۆژێک',
 	'FORUM_STATS'	=> 'ئامارەکانی مەکۆ',
 	'GZIP_COMPRESSION'	=> 'پەستاندنی GZip',
