@@ -156,6 +156,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'	=> 'پێویستە سەردێڕێک دیاری بکەیت لە کاتی نووسینی پەیامێکی نوێدا.',
 	'ENABLED'	=> 'چالاککراو',
 	'ENCLOSURE'	=> 'پەرژینکردن',
+	'ENTER_USERNAME'					=> 'ناوی بەکارهێنەر بنووسە',
 	'ERR_CHANGING_DIRECTORY'	=> 'نەتوانرا بوخچە بگۆڕدرێت.',
 	'ERR_CONNECTING_SERVER'	=> 'هەڵە ڕوویدا لە پەیوەندیکردن بە ڕاژەکارەوە.',
 	'ERR_JAB_AUTH'	=> 'نەتوانرا ڕێگە پێبدرێت لە ڕاژەکاری جابەر.',
@@ -190,6 +191,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'تکایە کرتە لێرە بکە بۆ بینینی یاساکانی مەکۆ',
 	'FROM'	=> 'لەلایەن',
 	'FSOCK_DISABLED'	=> 'نەتوانرا ئەو کردەیە بە ئەنجام بگەیەنرێت لەبەر ئەوەی فرمانی <var>fsockopen</var> ناچالاککراوە یان نەتوانراوە پرسی ڕاژەکار بدۆزرێتەوە.',
+	'FSOCK_TIMEOUT'			=> 'وەستانێک ڕوویدا لەکاتی خوێندنەوە لە تەوژمی ڕایەڵەکە.',
 	'FTP_FSOCK_HOST'	=> 'خانەخوێی FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'	=> 'ڕاژەکاری FTP بەکاربرا بۆ پەیوەندیکردن بە وێبگەکەتەوە.',
 	'FTP_FSOCK_PASSWORD'	=> 'تێپەڕەوشەی FTP',
@@ -622,6 +624,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'	=> '<strong>%d</strong> پەیامی نەخوێندراوە',
 	'UNREAD_POST'			=> 'پەیامی نەخوێندراو',
 	'UNREAD_POSTS'			=> 'پەیامە نەخوێندراوەکان',
+	'UNWATCH_FORUM_CONFIRM'		=> 'دڵنیایت کە دەتەوێ بەشداریپێکردنت لەو مەکۆیە لادەیت؟',
+	'UNWATCH_FORUM_DETAILED'	=> 'دڵنیایت کە دەتەوێ بەشداریپێکردنت لەو مەکۆیە “%s” لادەیت؟',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'دڵنیایت کە دەتەوێ بەشداریپێکردنت لەو بابەتە لادەیت؟',
+	'UNWATCH_TOPIC_DETAILED'	=> 'دڵنیایت کە دەتەوێ بەشداریپێکردنت لەو بابەتە “%s” لادەیت؟',
 	'UNWATCHED_FORUMS'	=> 'چیتر بەشدار نیت لە مەکۆ دیاریکراوەکاندا.',
 	'UNWATCHED_TOPICS'	=> 'چیتر بەشدار نیت لە بابەتە دیاریکراوەکاندا.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'چیتر بەشدار نیت لە یەکە دیاریکراوەکاندا.',
@@ -667,6 +673,10 @@ $lang = array_merge($lang, array(
 	'VISIT_WEBSITE'	=> 'سەردانی وێبگە بکە',
 	'WARNINGS'	=> 'ئاگادارییەکان',
 	'WARN_USER'	=> 'بەکارهێنەر ئاگادار بکەوە',
+	'WATCH_FORUM_CONFIRM'	=> 'دڵنیایت کە دەتەوێ بەشداربیت لەو مەکۆیە؟',
+	'WATCH_FORUM_DETAILED'	=> 'دڵنیایت کە دەتەوێ بەشداربیت لەو مەکۆیە “%s” ؟',
+	'WATCH_TOPIC_CONFIRM'	=> 'دڵنیات کە دەتەوێ بەشداربیت لەو بابەتە؟',
+	'WATCH_TOPIC_DETAILED'	=> 'دڵنیایت کە دەتەوێ بەشداربیت لەو بابەتە “%s” ؟',
 	'WELCOME_SUBJECT'	=> 'بەخێربێیت بۆ مەکۆکانی %s',
 	'WEBSITE'	=> 'وێبگە',
 	'WHOIS'	=> 'Whois',
