@@ -127,6 +127,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'	=> 'وێنەی هەنووکەیی',
 	'CURRENT_PASSWORD'	=> 'تێپەڕەوشەی هەنووکە',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'پێویستە دڵنیا بیت لە تێپەڕەوشەی هەنووکەییت ئەگەر ئەتەوێت بیگۆڕیت، ناونیشانی ئیمەیل یان ناوی بەکارهێنەر بگۆڕە.',
+	'CUR_PASSWORD_EMPTY'		=> 'تۆ تێپەڕەوشەی ئێستات نەنووسیوە.',
 	'CUR_PASSWORD_ERROR'	=> 'تێپەڕەوشەی هەنووکە کە لێتداوە نەگونجاوە.',
 	'CUSTOM_DATEFORMAT'	=> 'دەستکرد...',
 	'DEFAULT_ACTION'	=> 'چالاکی بنەڕەت',
@@ -246,9 +247,11 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'	=> 'هەڵەیەک ڕوویدا لە کاتی گواستنەوەی پەیام بۆ بوخچەی نوێ، تەنها %1d لە %2d پەیام گواسترانەوە.',
 	'MOVE_TO_FOLDER'	=> 'گواستنەوە بۆ بوخچە',
 	'MOVE_UP'	=> 'جوڵان بۆ سەرەوە',
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'تۆ دووبارە ئیمەیڵەکەت نەنووسیوەتەوە.',
 	'NEW_EMAIL_ERROR'	=> 'ئەو ناونیشانی ئیمەیلانەی نووسیوتن وەک یەک نین.',
 	'NEW_FOLDER_NAME'	=> 'ناوی بوخچەی نوێ',
 	'NEW_PASSWORD'	=> 'تێپەڕەوشەی نوێ',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'تۆ دووبارە تێپەڕەوشەکەت نەنووسیوەتەوە.',
 	'NEW_PASSWORD_ERROR'	=> 'ئەو تێپەڕەوشانەی نووسیوتن وەک یەک نین.',
 	'NOTIFY_METHOD'	=> 'ڕێبازی ئاگادارکردنەوە',
 	'NOTIFY_METHOD_BOTH'	=> 'هەردوو',
